@@ -177,12 +177,10 @@ public:
     QImage::Format format() const
     {
         auto format = QImage::Format_Invalid;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
         if (m_pb.colorCount() == 4) {
             if (m_pb.bitMask() == 15)
                 format = QImage::Format_CMYK8888;
         }
-#endif
         if (m_pb.colorCount() == 3) {
             if (m_pb.bitMask() == 7)
                 format = QImage::Format_RGB888;
@@ -216,7 +214,7 @@ public:
         auto v = QString::fromLatin1(pchar_t(res.data()), res.size()).toDouble(&ok);
         if (ok && v > 0) {
             if (m_pb._unitsOfMeasurement) { // Inches
-                return qRoundOrZero(width() / v / 25.4 * 1000);
+                return dpi2ppm(width() / v);
             }
             // Millimeters
             return qRoundOrZero(width() / v * 1000);
@@ -230,7 +228,7 @@ public:
         auto v = QString::fromLatin1(pchar_t(res.data()), res.size()).toDouble(&ok);
         if (ok && v > 0) {
             if (m_pb._unitsOfMeasurement) { // Inches
-                return qRoundOrZero(height() / v / 25.4 * 1000);
+                return dpi2ppm(height() / v);
             }
             // Millimeters
             return qRoundOrZero(height() / v * 1000);
@@ -330,7 +328,7 @@ bool ScitexHandler::canRead() const
 bool ScitexHandler::canRead(QIODevice *device)
 {
     if (!device) {
-        qWarning("ScitexHandler::canRead() called with no device");
+        qCWarning(LOG_SCTPLUGIN) << "ScitexHandler::canRead() called with no device";
         return false;
     }
     ScitexHandlerPrivate hp;
@@ -344,7 +342,7 @@ bool ScitexHandler::read(QImage *image)
 {
     auto dev = device();
     if (dev == nullptr) {
-        qWarning("ScitexHandler::read() called with no device");
+        qCWarning(LOG_SCTPLUGIN) << "ScitexHandler::read() called with no device";
         return false;
     }
     if (!d->loadHeader(dev)) {
